@@ -8,6 +8,7 @@ from persisty.store.restrict_access_store import restrict_access_store
 from persisty.store.schema_validating_store import SchemaValidatingStore
 from persisty.store.store_abc import StoreABC
 from persisty.store_meta import StoreMeta
+from persisty.trigger.wrapper import triggered_store
 
 
 @dataclass
@@ -22,4 +23,5 @@ class MemStoreFactory:
         store = MemStore(self.store_meta, self.items)
         store = SchemaValidatingStore(store)
         store = restrict_access_store(store, self.store_meta.store_access)
+        store = triggered_store(store)
         return store
