@@ -5,6 +5,7 @@ from marshy.factory.impl_marshaller_factory import get_impls
 
 from persisty.impl.sqlalchemy.sqlalchemy_context import SqlalchemyContext
 
+_DEFAULT_CONTEXT = None
 
 class SqlalchemyContextFactoryABC(ABC):
     priority: int = 100
@@ -21,3 +22,10 @@ def create_default_context() -> Optional[SqlalchemyContext]:
         context = factory().create()
         if context:
             return context
+
+
+def get_default_context() -> Optional[SqlalchemyContext]:
+    global _DEFAULT_CONTEXT
+    if not _DEFAULT_CONTEXT:
+        _DEFAULT_CONTEXT = create_default_context()
+    return _DEFAULT_CONTEXT
